import { defineNuxtModule, createResolver, addComponent, addImports, addTypeTemplate } from '@nuxt/kit';

const module = defineNuxtModule({
  meta: {
    name: "nuxt-codemirror",
    configKey: "nuxtCodemirror"
  },
  // Default configuration options of the Nuxt module
  defaults: {},
  setup(_options, _nuxt) {
    const { resolve } = createResolver(import.meta.url);
    addComponent({
      name: "NuxtCodeMirror",
      filePath: resolve("./runtime/components/NuxtCodeMirror.vue")
    });
    addImports({
      name: "useNuxtCodeMirror",
      as: "useNuxtCodeMirror",
      from: resolve("./runtime/composables/useNuxtCodeMirror.ts")
    });
    addTypeTemplate({
      filename: "nuxt-codemirror.d.ts",
      src: resolve("./runtime/types/nuxt-codemirror.d.ts")
    });
    _nuxt.hook("vite:extendConfig", (config) => {
      config.resolve = config.resolve || {};
      config.resolve.alias = config.resolve.alias || {};
      config.resolve.alias["@codemirror/state"] = resolve(_nuxt.options.rootDir, "node_modules/@codemirror/state");
    });
  }
});

export { module as default };
